# * Author: Thomas Koetzing, Thomas@KoetzingIT.de
# * Download at http://www.KoetzingIT.de
# * Created: 03/18/2017
# * Last Update: 03/18/2017
# * Version: 1..0
# *
# * Purpose:
# * Set a new, custom ICON for a delivery group using a source icon file.
# * 
# * Usage:
# * 		New-DeliveryGroup-Icon <path to ico file> <delivery group name>
# * 
# * Note:
# * To see the custom icons in StoreFront, you need to diable Substitute Desktop Images
# * PoSH: Disable-DSStoreSubstituteDesktopImage -SiteId 1 -VirtualPath /Citrix/Store
# * 
# * Help: PNG files can be coverted to ico at http://convertico.com/
# *
# * Version History:  v1.0 initial release 03/18/17 (Thomas Koetzing)
# * 
# *****************************************************************

# *****************************************************************
# * Covert ICO to base64 and apply to delivery group
# *****************************************************************
Param(
	[String]$path,
	[String]$DeliveryGroup
)

# *****************************************************************
# * Check input
# *****************************************************************
If (!$path -or !$DeliveryGroup )
	{ Write-Host "Error! Usage: New-DeliveryGroup-Icon <path to ico file> <delivery group name>" }
 else {
	$base64Icon = [convert]::ToBase64String((get-content $path -encoding byte))
	$brokerIcon = New-BrokerIcon -EncodedIconData $base64Icon
	$desktopGroup = Get-BrokerDesktopGroup -Name $DeliveryGroup
	Set-BrokerDesktopGroup $desktopGroup -IconUid $brokerIcon.Uid 
 }